aboutsummaryrefslogtreecommitdiff
path: root/bpkg/pkg-unpack.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2015-10-05 08:45:27 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2015-10-05 08:45:27 +0200
commitb83a9bbdb0407c198e615e61491e1f8492ae5dc9 (patch)
treece421f55b5b1aa020c6edc3caefc321bbca44157 /bpkg/pkg-unpack.cxx
parent5ae8a9214da9285aa6e7e374288eaf9adc1ba862 (diff)
Add repository location to package, minor cleanups
Diffstat (limited to 'bpkg/pkg-unpack.cxx')
-rw-r--r--bpkg/pkg-unpack.cxx4
1 files changed, 3 insertions, 1 deletions
diff --git a/bpkg/pkg-unpack.cxx b/bpkg/pkg-unpack.cxx
index 5fc5f0b..b6decca 100644
--- a/bpkg/pkg-unpack.cxx
+++ b/bpkg/pkg-unpack.cxx
@@ -57,12 +57,14 @@ namespace bpkg
if (ad.sub (ac))
ad = ad.leaf (ac);
// Add the package to the configuration.
//
shared_ptr<package> p (new package {
move (m.name),
move (m.version),
state::unpacked,
+ repository_location (),
nullopt, // No archive
false, // Don't purge archive.
move (ad),
@@ -57,12 +57,14 @@ namespace bpkg
if (ad.sub (ac))
ad = ad.leaf (ac);
- // Add the package to the configuration.
+ // Add the package to the configuration. Use the special root
+ // repository as the repository of this package.
//
shared_ptr<package> p (new package {